package proxy.command;

import java.util.Locale;

import com.google.common.collect.Collections2;

import proxy.Proxy;
import proxy.handler.ProxyHandler;
import proxy.util.Formatter;

public class CommandHelp extends Command {
	public String getName() {
		return "help";
	}
	
	public String getHelp() {
		return "Displays proxy and server command help";
	}
	
	public String getArgs() {
		return "[command]";
	}
	
	private static String formatCommand(Command cmd) {
		String args = cmd.getArgs();
		return Formatter.DARK_GRAY + "/" + Formatter.AQUA + cmd.getName() + (args == null || args.isEmpty() ? "" : Formatter.GREEN + " " + args) 
			+ Formatter.GRAY + " - " + Formatter.YELLOW + cmd.getHelp();
	}

	public void run(Proxy proxy, ProxyHandler player, String[] args) {
		if(args.length == 0) {
			for(Command cmd : proxy.getCommands().values()) {
				if(cmd.canUse(player))
					sendMessage(player, formatCommand(cmd));
			}
			return;
		}
		Command cmd = proxy.getCommands().get(args[0].toLowerCase(Locale.US));
		if(cmd == null)
			throw new RunException("Command '%s' not found", args[0]);
		if(!cmd.canUse(player))
			throw new RunException("Command '%s' can not be used", args[0]);
		sendMessage(player, formatCommand(cmd));
	}
	
	public Iterable<String> complete(Proxy proxy, ProxyHandler player, String[] args, String[] serverMatches) {
		return args.length == 1 ? Collections2.filter(proxy.getCommands().keySet(), name -> proxy.getCommands().get(name).canUse(player)) : null;
	}
}
