package proxy.command;

import com.google.common.collect.Collections2;

import proxy.Proxy;
import proxy.handler.ProxyHandler;
import proxy.util.Formatter;

public class CommandTell extends Command {
	public String getName() {
		return "tell";
	}
	
	public String getHelp() {
		return "Sends a message to a player";
	}
	
	public String getArgs() {
		return "<player> <message ...>";
	}

	public int getRedactedLogArg(int args) {
		return 1;
	}

	public void run(Proxy proxy, ProxyHandler player, String[] args) {
		if(args.length < 2)
			throw new RunException("Please provide a player name and a message");
		ProxyHandler plr = proxy.getPlayer(args[0]);
		if(plr == null)
			throw new RunException("'%s' is not online", args[0]);
		if(plr == player)
			throw new RunException("You cannot message yourself");
		String msg = Formatter.joinSpace(1, args);
		plr.sendMessage(Formatter.AQUA + "%s" + Formatter.GREEN + " -> " + Formatter.GRAY + "%s", player == null ? "#CONSOLE#" : player.getUsername(), msg);
		sendMessage(player, Formatter.AQUA + "%s" + Formatter.RED + " <- " + Formatter.GRAY + "%s", plr.getUsername(), msg);
	}
	
	public Iterable<String> complete(Proxy proxy, ProxyHandler player, String[] args, String[] serverMatches) {
		return args.length == 1 ? (player == null ? proxy.getPlayerNames() : Collections2.filter(proxy.getPlayerNames(), name -> proxy.getPlayer(name) != player)) : null;
	}
}
