package proxy.handler;

import proxy.Proxy;
import proxy.network.Connection;
import proxy.network.Packet;

public interface Handler {
	public static final class ThreadQuickExitException extends RuntimeException {
		public static final ThreadQuickExitException INSTANCE = new ThreadQuickExitException();

		private ThreadQuickExitException() {
			this.setStackTrace(new StackTraceElement[0]);
		}

		public synchronized Throwable fillInStackTrace() {
			this.setStackTrace(new StackTraceElement[0]);
			return this;
		}
	}
	
	static <T extends Handler> void syncToMain(final Packet<T> packet, final T handler, Proxy proxy) throws ThreadQuickExitException {
		if(!proxy.isMainThread()) {
			proxy.schedule(new Runnable() {
				public void run() {
					packet.processPacket(handler);
				}
			});
			throw ThreadQuickExitException.INSTANCE;
		}
	}

	void onDisconnect(Connection connection, String reason);
	default void update(Connection connection) {
	}
}
