package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S01PacketJoinGame extends EntityIdPacketClient implements Packet<ProxyHandler>
{
    private boolean hardcoreMode;
    private byte gameType;
    private int dimension;
    private byte difficulty;
    private int maxPlayers;
    private String worldType;
    private boolean reducedDebugInfo;

    public S01PacketJoinGame()
    {
    }

    public S01PacketJoinGame(int entityIdIn, boolean spectator)
    {
        this.entityId = entityIdIn;
        this.dimension = 0;
        this.difficulty = 2;
        this.gameType = (byte)(spectator ? 3 : 0);
        this.maxPlayers = 1;
        this.hardcoreMode = false;
        this.worldType = "flat";
        this.reducedDebugInfo = false;
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.entityId = buf.readInt();
        int i = buf.readUnsignedByte();
        this.hardcoreMode = (i & 8) == 8;
        i = i & -9;
        this.gameType = (byte)i;
        this.dimension = buf.readByte();
        this.difficulty = (byte)buf.readUnsignedByte();
        this.maxPlayers = buf.readUnsignedByte();
        this.worldType = buf.readStringFromBuffer(16);
        this.reducedDebugInfo = buf.readBoolean();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeInt(this.entityId);
        int i = this.gameType;

        if (this.hardcoreMode)
        {
            i |= 8;
        }

        buf.writeByte(i);
        buf.writeByte(this.dimension);
        buf.writeByte(this.difficulty);
        buf.writeByte(this.maxPlayers);
        buf.writeString(this.worldType);
        buf.writeBoolean(this.reducedDebugInfo);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleJoinGame(this);
    }

    public int getEntityId()
    {
        return this.entityId;
    }

    public boolean isHardcoreMode()
    {
        return this.hardcoreMode;
    }

    public byte getGameType()
    {
        return this.gameType;
    }

    public int getDimension()
    {
        return this.dimension;
    }

    public byte getDifficulty()
    {
        return this.difficulty;
    }

    public int getMaxPlayers()
    {
        return this.maxPlayers;
    }

    public String getWorldType()
    {
        return this.worldType;
    }

    public boolean isReducedDebugInfo()
    {
        return this.reducedDebugInfo;
    }
}
