package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S03PacketTimeUpdate implements Packet<ProxyHandler>
{
    private long totalWorldTime;
    private long worldTime;

    public S03PacketTimeUpdate()
    {
    }

    public S03PacketTimeUpdate(long totalTimeIn, boolean doDayLightCycle)
    {
        this.totalWorldTime = totalTimeIn;
        this.worldTime = totalTimeIn;

        if (!doDayLightCycle)
        {
            this.worldTime = -this.worldTime;

            if (this.worldTime == 0L)
            {
                this.worldTime = -1L;
            }
        }
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.totalWorldTime = buf.readLong();
        this.worldTime = buf.readLong();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeLong(this.totalWorldTime);
        buf.writeLong(this.worldTime);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleTimeUpdate(this);
    }
}
