package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S07PacketRespawn implements Packet<ProxyHandler>
{
    private int dimensionID;
    private byte difficulty;
    private byte gameType;
    private String worldType;

    public S07PacketRespawn()
    {
    }

    public S07PacketRespawn(S01PacketJoinGame pkt)
    {
        this.dimensionID = pkt.getDimension();
        this.difficulty = pkt.getDifficulty();
        this.gameType = pkt.getGameType();
        this.worldType = pkt.getWorldType();
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleRespawn(this);
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.dimensionID = buf.readInt();
        this.difficulty = (byte)buf.readUnsignedByte();
        this.gameType = (byte)buf.readUnsignedByte();
        this.worldType = buf.readStringFromBuffer(16);
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeInt(this.dimensionID);
        buf.writeByte(this.difficulty);
        buf.writeByte(this.gameType);
        buf.writeString(this.worldType);
    }

    public byte getGameType()
    {
        return this.gameType;
    }
}
