package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S2BPacketChangeGameState implements Packet<ProxyHandler>
{
    private int state;
    private float value;

    public S2BPacketChangeGameState()
    {
    }

    public S2BPacketChangeGameState(int stateIn, float p_i45194_2_)
    {
        this.state = stateIn;
        this.value = p_i45194_2_;
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.state = buf.readUnsignedByte();
        this.value = buf.readFloat();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeByte(this.state);
        buf.writeFloat(this.value);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleChangeGameState(this);
    }
    
    public int getType() {
    	return this.state;
    }
    
    public int getIntValue() {
    	float value = this.value + 0.5f;
        int v = (int)value;
        return value < (float)v ? v - 1 : v;
    }
    
    public float getFloatValue() {
    	return this.value;
    }
}
