package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S3CPacketUpdateScore implements Packet<ProxyHandler>
{
    private static enum Action
    {
        CHANGE,
        REMOVE;
    }
    
    private String name = "";
    private String objective = "";
    private int value;
    private S3CPacketUpdateScore.Action action;
    
    public S3CPacketUpdateScore() {
    }
    
    public S3CPacketUpdateScore(String name, String objective, int value, boolean remove) {
    	this.name = name;
    	this.objective = objective;
    	this.value = value;
    	this.action = remove ? Action.REMOVE : Action.CHANGE;
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.name = buf.readStringFromBuffer(40);
        this.action = (S3CPacketUpdateScore.Action)buf.readEnumValue(S3CPacketUpdateScore.Action.class);
        this.objective = buf.readStringFromBuffer(16);

        if (this.action != S3CPacketUpdateScore.Action.REMOVE)
        {
            this.value = buf.readVarIntFromBuffer();
        }
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeString(this.name);
        buf.writeEnumValue(this.action);
        buf.writeString(this.objective);

        if (this.action != S3CPacketUpdateScore.Action.REMOVE)
        {
            buf.writeVarIntToBuffer(this.value);
        }
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
    }
}
