package proxy.packet;

import java.io.IOException;
import java.util.Collection;

import com.google.common.collect.Lists;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S3EPacketTeams implements Packet<ProxyHandler>
{
    private String name = "";
    private String displayName = "";
    private String prefix = "";
    private String suffix = "";
    private String nameTagVisibility;
    private int color;
    private Collection<String> players;
    private int action;
    private int friendlyFlags;
    
    private static String getSortedTeamName(int sort, String player) {
    	sort ^= 0x80000000;
    	char[] chars = new char[10];
    	for(int z = 0; z < 2; z++) {
    		chars[z] = (char)((sort >> ((1 - z) * 16)) & 0xffff);
    	}
        for(int z = 0; z < 8; z++) {
        	chars[z + 2] = (char)((z < player.length() ? player.charAt(z / 2) : 0) << 8 | (z + 1 < player.length() ? player.charAt(z / 2 + 1) : 0));
        }
        return new String(chars);
    }

    public S3EPacketTeams()
    {
        this.nameTagVisibility = "always";
        this.color = -1;
        this.players = Lists.newArrayList();
    }

    public S3EPacketTeams(int action, int sort, String prefix, String suffix, String player)
    {
        this.nameTagVisibility = "always";
        this.color = -1;
        this.players = Lists.newArrayList(player);
        this.friendlyFlags = 1;
        this.action = action;
        this.name = getSortedTeamName(sort, player);
        this.displayName = "";
        this.prefix = prefix;
        this.suffix = suffix;
    }
    
    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.name = buf.readStringFromBuffer(16);
        this.action = buf.readByte();

        if (this.action == 0 || this.action == 2)
        {
            this.displayName = buf.readStringFromBuffer(32);
            this.prefix = buf.readStringFromBuffer(16);
            this.suffix = buf.readStringFromBuffer(16);
            this.friendlyFlags = buf.readByte();
            this.nameTagVisibility = buf.readStringFromBuffer(32);
            this.color = buf.readByte();
        }

        if (this.action == 0 || this.action == 3 || this.action == 4)
        {
            int i = buf.readVarIntFromBuffer();

            for (int j = 0; j < i; ++j)
            {
                this.players.add(buf.readStringFromBuffer(40));
            }
        }
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeString(this.name);
        buf.writeByte(this.action);

        if (this.action == 0 || this.action == 2)
        {
            buf.writeString(this.displayName);
            buf.writeString(this.prefix);
            buf.writeString(this.suffix);
            buf.writeByte(this.friendlyFlags);
            buf.writeString(this.nameTagVisibility);
            buf.writeByte(this.color);
        }

        if (this.action == 0 || this.action == 3 || this.action == 4)
        {
            buf.writeVarIntToBuffer(this.players.size());

            for (String s : this.players)
            {
                buf.writeString(s);
            }
        }
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
    }
}
