package proxy.util;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.lang.ProcessBuilder.Redirect;
import java.util.Map;
import java.util.Map.Entry;

import com.google.common.base.Charsets;
import com.google.common.io.Resources;

import proxy.Proxy;

public class SpigotProcess extends SubProcess {
	private final int port;
	
	public SpigotProcess(Proxy proxy, String name, int port) {
		super(proxy, name);
		this.port = port;
	}
	
	protected Process createProcess() throws IOException {
		final Process process = new ProcessBuilder(
			this.proxy.getSpigotJavaPath().isEmpty() ? getJavaDir() : this.proxy.getSpigotJavaPath(), 
			"-Xmx" + this.proxy.getSpigotMaxMem() + "m", 
			"-jar", "pandaspigot.jar"
		).directory(this.dir).redirectOutput(Redirect.PIPE).redirectErrorStream(true).redirectInput(Redirect.PIPE).start();

		Thread con = new Thread(new Runnable() {
			private final BufferedReader reader = new BufferedReader(new InputStreamReader(new BufferedInputStream(process.getInputStream())));
			
			public void run() {
				while(true) {
					String line;
					try {
						line = this.reader.readLine();
					}
					catch(IOException e) {
						line = null;
					}
					if(line == null)
						break;
					Log.infoAs("Server " + SpigotProcess.this.name, line);
				}
			}
		}, this.name + " console");
		con.setDaemon(true);
		con.start();
		return process;
	}
	
	private Map<String, String> getVarMap() {
		Map<String, String> map = this.proxy.getOptions();
		map.put("port", "" + this.port);
		map.put("schematicsDir", new File("schematics").getAbsolutePath());
		return map;
	}
	
	private void copyFile(String template, String dest) {
		String content;
		try {
			content = Resources.toString(Resources.getResource(template), Charsets.UTF_8);
		}
		catch(IOException e) {
			Log.error(e, "Could not read %s", template);
			return;
		}
		for(Entry<String, String> entry : this.getVarMap().entrySet()) {
			content = content.replace("[#" + entry.getKey() + "]", entry.getValue());
		}
		createFile(dest, content);
	}
	
	protected String getStopCommand() {
		return "stop";
	}
	
	protected void setup() {
		this.copyJar("pandaspigot.jar", "pandaspigot.jar");
		this.copyJar("worldedit.jar", "plugins/worldedit.jar");
		
		this.copyFile("server.tmp", "server.properties");
		this.copyFile("bukkit.tmp", "bukkit.yml");
		this.copyFile("spigot.tmp", "spigot.yml");
		this.copyFile("paper.tmp", "paper.yml");
		this.copyFile("panda.tmp", "pandaspigot.yml");
		this.copyFile("worldedit.tmp", "plugins/WorldEdit/config.yml");
		
		this.createFile("eula.txt", "eula=true");
		this.createFile("help.yml", "");
		this.createFile("permissions.yml", "");
		this.createFile("ops.json", "[]");
		this.createFile("whitelist.json", "[]");
		this.createFile("usercache.json", "[]");
		this.createFile("banned-players.json", "[]");
		this.createFile("banned-ips.json", "[]");
		this.createFile("commands.yml", "command-block-overrides: []\naliases:\n  icanhasbukkit:\n  - version $1-");
		this.createFile("wepif.yml", "ignore-nijiperms-bridges: true\nresolvers:\n    enabled:\n    - DinnerPermsResolver\n    disabled:\n    - PluginPermissionsResolver\n    - PermissionsExResolver\n    - bPermissionsResolver\n    - GroupManagerResolver\n    - NijiPermissionsResolver\n    - FlatFilePermissionsResolver\npermissions:\n    groups:\n        default:\n            permissions: []\n        admins:\n            permissions:\n            - '*'\n    users: []");
		this.createFile("plugins/bStats/config.yml", "enabled: false\nserverUuid: 11111111-1111-1111-1111-111111111111\nlogFailedRequests: false\nlogSentData: false\nlogResponseStatusText: false");
	}
}
