package proxy.util;

import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
import java.io.File;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.util.Locale;

import com.google.common.base.Charsets;
import com.google.common.io.Files;

import proxy.Proxy;

public abstract class SubProcess {
	protected final Proxy proxy;
	protected final File dir;
	protected final String name;
	
	protected Process process;
	protected PrintWriter writer;
	
	public SubProcess(Proxy proxy, String name) {
		this.proxy = proxy;
		this.name = name;
		this.dir = new File(name);
	}
	
	protected static String getJavaDir() {
		String separator = System.getProperty("file.separator");
		String path = System.getProperty("java.home") + separator + "bin" + separator;
		return System.getProperty("os.name").toLowerCase(Locale.US).contains("win") && (new File(path + "javaw.exe")).isFile() ? path + "javaw.exe" : path + "java";
	}
	
	protected void copyJar(String jar, String dest) {
		File src = new File(new File("jars"), jar);
		File dst = new File(this.dir, dest);
		dst.getParentFile().mkdirs();
		try {
			Files.copy(src, dst);
		}
		catch(IOException e) {
			Log.error(e, "Could not copy %s to %s", src, dst);
		}
	}
	
	protected void createFile(String dest, String content) {
		File dst = new File(this.dir, dest);
		dst.getParentFile().mkdirs();
		try {
			Files.write(content, dst, Charsets.UTF_8);
		}
		catch(IOException e) {
			Log.error(e, "Could not write %s", dst);
		}
	}
	
	public boolean start() {
		this.dir.mkdirs();
		this.setup();
		try {
			this.process = this.createProcess();
		}
		catch(IOException e) {
			Log.error(e, "Could not start process for %s", this.name);
			return false;
		}
		this.writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(new BufferedOutputStream(this.process.getOutputStream()))), true);
		return true;
	}
	
	protected abstract Process createProcess() throws IOException;

	protected abstract void setup();
	
	protected abstract String getStopCommand();
	
	public void shutdown() {
		if(this.writer != null) {
			try {
				this.writer.println(this.getStopCommand());
			}
			catch(Exception e) {
			}
		}
		if(this.process != null) {
			try {
				this.process.waitFor();
			}
			catch(InterruptedException e) {
				Log.error(e, "Interrupted while waiting for process of %s to terminate", this.name);
			}
		}
	}
	
	public void runCommand(String cmd) {
		if(this.writer != null) {
			try {
				this.writer.println(cmd);
			}
			catch(Exception e) {
			}
		}
	}
}
